<?php

/* 
 * IntelliTheme Options and Custom Functions
  */


  
// ------------------------------------ //
// Theme and Functoins Setup //
// ------------------------------------ //

// include needed files
include('theme_update.php'); // Include automatic updater

// include classes
include('classes/preset_name.php'); // all preset names stored as constants
include('classes/intellitheme_sidebar.php'); // include sidebar classes

// enable advanced WordPress support
add_theme_support( 'menus' );
register_nav_menu( PresetName::EASTSIDE, 'EastSide Preset' );



// ---------------------------------- //
// Preset Rotating Functions //
// ---------------------------------- //


add_action( 'init', 'asf_save_preset_to_session' );

function asf_save_preset_to_session() {
	
	session_start();
  
  // check if current preset is set
  // otherwise we need to clear the session and start again
        
     /**
      * COMMENT BY JOHN SHIPP
      * Looks for the session variable that controls which preset will display.
      * If it's not set, the user hasn't been here before (or, it's timed out)
      * so we'll set a new session variable using the asf_master_rotator function. 
      */
     if (!isset($_SESSION['asf_current_preset'])) {
         asf_master_rotator();
     }
        
}


function asf_master_rotator() {

	$ad_options = get_option('preset_ad_code');
	$options = $ad_options['preset_select_option'];
    $weight = $ad_options['preset_weight_option']; 
	
	
	/* if $options are not set (like when the theme is installed, we need to still
	 * have $options be an array. If $options are NULL or EMPTY, array_keys and 
	 * array_rand throws an error.
	 **/
	if ( !isset($options) || empty($options) ) {
		$options = array( PresetName::TOWER_RIGHT => 'on');
	}
			
	$presetSelect = array();
	$presetWeights = array();

	for ($x = 1; $x <= 999; $x++) {
			
		// if the value of $options[] is 'on' then set that value's 
		// key to an item in the $PresetSelect array
		$presetSelect = array_keys($options, 'on');
	}

        foreach ($presetSelect as $k => $v){
            $presetWeights[$k] = $weight[$v];
        }


        // select random theme by weighting value 
        $displayPreset = asf_weighted_random_simple($presetSelect, $presetWeights);

        
        /**
         * At this point, we should have figured out the preset to display, and,
         * we should only be INSIDE of this function IF the user needs a new
         * preset anyway... so... we'll just set the session.
         */
        $_SESSION['asf_current_preset'] = $displayPreset;
        
       
	  
}



/**
 * asf_weighted_random_simple()
 * Pick a random item based on weights.
 *
 * @param array $values Array of elements to choose from
 * @param array $weights An array of weights. Weight must be a positive number.
 * @return mixed Selected element.
 */
function asf_weighted_random_simple($values, $weights){
    $count = count($values);
    $i = 0;
    $n = 0;
    $num = mt_rand(0, array_sum($weights));
    while($i < $count){
        $n += $weights[$i];
        if($n >= $num){
            break;
        }
        $i++;
    }
    return $values[$i];
}


// ------------------------------------------- //
// Adsense Flippers Theme Fuctions //
// ------------------------------------------- //


add_action('after_setup_theme', 'asf_theme_setup');

function asf_theme_setup()
{
  global $intellitheme_default_colors, $intellitheme_default_fonts;
  
    if (isset($_POST['reset_all_yes']))
    {
      if (wp_verify_nonce($_POST['_wpnonce'], 'reset_to_default'))
      {
        delete_option('preset_ad_code');
      } else {
        echo 'nonce error';
      }
    }
  
  
  // Default Settings
  $intellitheme_default_colors = array(PresetName::TOWER_RIGHT => array(
        '#999999', 
        '#1b337b',
        '#FFFFFF',
        '#9cb7fe',
        '#2B489B',
        '#1b337b'
      ),
     PresetName::TOWER_LEFT => array(        
        '#999999', 
        '#1b337b',
        '#FFFFFF',
        '#9cb7fe',
        '#2B489B',
        '#1b337b'
      ),

     PresetName::CENTRAL_BANK => array(
        '#333333', 
        '#1b337b',
        '#0000EE',
        '#32527A'
      ),
     PresetName::EASTSIDE => array(
        '#333333', 
        '#000000',
        '#000000',
        '#000000'
      ),
     PresetName::SANDLOT => array(
        '#FFFFFF', 
        '#FFFFFF',
        '#0000EE',
        '#FFFFFF'
      ),     
  );
  
  
  $intellitheme_default_fonts = array(PresetName::TOWER_RIGHT => array(
        ' "Lucida Grande", "Lucida Sans Unicode", "Lucida Sans" ', '36',
        'Helvetica, Arial, Sans-Serif', '24',
		'Helvetica, Arial, Sans-Serif', '17',
        'Arial', '17',
        'Verdana', '13',
    	  'Verdana', '13'
        ),
     PresetName::TOWER_LEFT => array(
        ' "Lucida Grande", "Lucida Sans Unicode", "Lucida Sans" ', '36',
        'Helvetica, Arial, Sans-Serif', '24',
		'Helvetica, Arial, Sans-Serif', '17',
        'Arial', '17',
        'Verdana', '13',
    	  'Verdana', '13'
        ),     
     PresetName::CENTRAL_BANK => array(
        'Arial', '36',
        'Arial', '20',
        'Arial', '20',
        'Arial', '15',
    	  'Arial', '13',
		  'Arial', '13'
        ),     
     PresetName::EASTSIDE => array(
        'Georgia' , '32',
        'Georgia', '30',
		'Georgia', '30',
        'Georgia', '18',
        'Arial', '15',
    	  'Arial', '15'
        ),
      PresetName::SANDLOT => array(
        'Georgia' , '18',
		'Georgia' , '24',
        'Georgia' , '24',
		'Georgia' , '16',
        'Arial', '13',
    	  'Arial', '13'
        ),
  );
    
  asf_theme_check_defaults();

  add_action('wp_print_scripts', 'asf_insert_scripts');
  add_action('admin_enqueue_scripts', 'asf_admin_scripts');
  add_action('wp_head', 'asf_ajax_tracking', 1);
  add_action('admin_footer', 'asf_admin_footer');
  add_action('get_footer', 'asf_init_tracking');
  add_action('wp_ajax_save_settings', 'asf_prefix_ajax_save_settings');  
}

function asf_theme_check_defaults()
{
  global $intellitheme_default_colors, $intellitheme_default_fonts;
  
  // Delete option (enable for testing only)
  // delete_option('preset_ad_code');
  
	$options = get_option('preset_ad_code');
  
  if (! is_array($options))
  {
    // nothing set yet
    // echo 'Setting defaults';
    $options['preset_select_option'] = array
    (
        PresetName::TOWER_RIGHT => 'on',
        PresetName::TOWER_LEFT => 'off',
        PresetName::CENTRAL_BANK => 'off',
        PresetName::EASTSIDE => 'off',
        PresetName::SANDLOT => 'off'
    );
    
    $options['preset_weight_option'] = array
    (
        PresetName::TOWER_RIGHT => 50,
        PresetName::TOWER_LEFT => 50,
        PresetName::CENTRAL_BANK => 50,
        PresetName::EASTSIDE => 50,
        PresetName::SANDLOT => 50
    );
    

    $theme_names = array(
      PresetName::TOWER_RIGHT,
      PresetName::TOWER_LEFT,
      PresetName::CENTRAL_BANK,
      PresetName::EASTSIDE,
      PresetName::SANDLOT
    );
    
	// Set all colors
    $theme_colors = array(
      'color_background',
      'color_header',
      'color_sidebar_left',
      'color_sidebar_right',
      'color_links',
      'color_footer'
    );
    
    $theme_fonts = array(
      'h1',
      'page_h2',
	  'post_h2',
      'h3',
      'content',
      'link'
    );
    
    foreach ($theme_names as $name)
    {
      $k = 0;
      
      $i = $name . '_indicator';
      $options[$i] = '';
      
      $i = $name . '_description_toggle';
      $options[$i] = 'on';
	  
	  $i = $name . '_g_image_break';
	  $options[$i] = 'on';
      
      $i = $name . '_above_content_linkunit'; 
      $options[$i] = '';
        
      $i = $name . '_below_post_title';
      $options[$i] = '';
       
      $i = $name . '_under_content';
      $options[$i] = '';
       
      $i = $name . '_sidebar_sky';       
      $options[$i] = '';
      
      foreach ($theme_colors as $color)
      {
	  
        $i = $name . '_' . $color;
        $options[$i] = $intellitheme_default_colors[$name][$k];
        $k++;
      }
      
      $k=0;
      foreach($theme_fonts as $font)
      {
        $i = $name . '_' . $font . '_font';
        $options[$i] = $intellitheme_default_fonts[$name][$k];
        $k++;
        $i = $name . '_' . $font . '_font_size';
        $options[$i] = $intellitheme_default_fonts[$name][$k];
        $k++;
      }
    }
    
    update_option('preset_ad_code', $options);
    
  }
  
  // set data_mining to 1 by default
  $options = get_option('data_mining');
  if ($options == '')
  {
    update_option('data_mining', 1);
  }
}

function asf_admin_footer()
{
  global $intellitheme_default_colors, $intellitheme_default_fonts;
  
?>

<?php
}

function asf_insert_scripts()
{
  wp_register_script('tracking', get_stylesheet_directory_uri() . '/js/tracking.js');
  
  wp_enqueue_script('jquery');
  
  wp_enqueue_script('tracking');
  
}

function asf_admin_scripts() {

  wp_register_script('jquery_ui', get_stylesheet_directory_uri(). '/js/jquery-ui-1.9.2.custom.min.js');
  // wp_register_script('jquery_colorpicker', get_stylesheet_directory_uri() . '/js/colorpicker.js');
  wp_register_script('jquery_colorpicker', get_stylesheet_directory_uri() . '/js/pickcolor.js');

  wp_enqueue_script('jquery');
  // wp_enqueue_script('thickbox');
  add_thickbox();
  
  wp_enqueue_script('farbtastic');
  wp_enqueue_script('jquery_colorpicker');

  wp_enqueue_script('jquery_ui');

  wp_register_style('jquery_ui_css', get_stylesheet_directory_uri(). '/css/ui-lightness/jquery-ui-1.8.21.custom.css');
  // wp_register_style('jquery_colorpicker_css', get_stylesheet_directory_uri(). '/css/colorpicker.css');

  wp_enqueue_style('jquery_ui_css'); 
  wp_enqueue_style('farbtastic'); 
  
}

function asf_init_tracking()
{  
  $preset = $_SESSION['asf_current_preset'];  
  ?>
  <script type="text/javascript">
  jQuery(document).ready(function(){
    currentTheme = '<?php echo $preset ?>';
  })
  </script>
  <?php
  
}

function asf_ajax_tracking()
{
  global $wpdb;
  
  // add extra field for page views
  $wpdb->show_errors();
  $preset = $_SESSION['asf_current_preset'];  
  
  $sql = "create table if not exists {$wpdb->prefix}tracking (
    created timestamp,
    url varchar(255),
    theme varchar(255),
    clicked enum('no', 'yes'),
    index (theme),
    index (url)
  )";
  $wpdb->query($sql);

  $sql = "show columns from {$wpdb->prefix}tracking where field = 'clicked'";
  $result = $wpdb->get_results($sql);
  // print_r($result);
  
  if (count($result) == 0)
  {
    $sql = "alter table {$wpdb->prefix}tracking 
      add clicked enum('no', 'yes')";
    $wpdb->query($sql);      
  }
  
  
  if ( (isset($_POST['action'])) and $_POST['action'] == 'tracking')
  {
    $sql = "insert into {$wpdb->prefix}tracking (url, theme, clicked)
      values ('%s', '%s', 'yes')";
    $sql = $wpdb->prepare($sql, $_POST['adUrl'], $_POST['presetTheme']);  
    $wpdb->query($sql);
    exit;
  } else {
    $sql = "insert into {$wpdb->prefix}tracking (url, theme, clicked)
      values ('%s', '%s', 'no')";
    $sql = $wpdb->prepare($sql, 
      'http://' . $_SERVER['HTTP_HOST'] . '/' . $_SERVER['REQUEST_URI'], 
      $preset);  
    $wpdb->query($sql);
  }
  
}


// Blog_description and title toggled on and off by changing CSS IDs
function asf_blog_title_toggle() {
	
	$options = get_option('preset_ad_code'); // preset_ad_code[{$theme_name}_description_toggle]
	$preset = $_SESSION['asf_current_preset'];
	
	if ($options[$preset . '_description_toggle'] == 'on' ) {
			?>
				<h1><a href="<?php echo get_bloginfo('url'); ?>"><?php bloginfo('name'); ?></a></h1>
				<div class="description"><?php bloginfo('description'); ?></div>
			<?php
		}
		else {
			?> <div id="no_blog_description">
					<h1><a href="<?php echo get_bloginfo('url'); ?>"><?php bloginfo('name'); ?></a></h1>
					<div class="description"><?php bloginfo('description'); ?></div>
				</div>
			<?php
		} 
	
}





// ----------------------- //
// Register Sidebars //
// ------------------ ---- //

add_action( 'widgets_init', 'asf_register_sidebars' );

function asf_register_sidebars() {

	/* Register the 'primary' sidebar. */
	register_sidebar( 
		array(
			'id' => 'above-ad',
			'name' => 'Above Ad Area',
			'description' => __( 'Place the widgets that you would like to appear above your sidebar ad here.' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>'
		)
	);

	register_sidebar( 
		array(
			'id' => 'below-ad',
			'name' => 'Below Ad Area',
			'description' => __( 'Place the widgets that you would like to appear below your sidebar ad here.' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>'
		)
	);
	
	
}



// -------------------------------------- //	
// Admin Menus and Theme Options Section  //
// -------------------------------------- //

// Adds AF Theme menu to Admin
add_action('admin_menu', 'asf_add_main_theme_menu'); 
add_action('admin_head', 'asf_admin_head');
add_action('admin_head', 'asf_add_metaboxes');
add_action('wp_insert_post', 'asf_save_meta_box');

function asf_add_metaboxes()
{
	add_meta_box( 'asf_ad_control', 'Show Ads', 'asf_display_meta_box', 'page', 'side', 'high');
	add_meta_box( 'asf_ad_control', 'Show Ads', 'asf_display_meta_box', 'post', 'side', 'high');
}

function asf_display_meta_box()
{
  global $post;
  $old_value = get_post_meta($post->ID, 'asf_ad_control', true);

  // The actual fields for data entry
  echo '<label for="price">' . 'Suppress ads for this content:' . '</label> ';
  echo '<input type="checkbox" ';
  if ($old_value)
  {
    echo ' checked="checked" ';
  }
  echo ' id="asf_ad_control" name="asf_suppress_ads" />';
}

function asf_save_meta_box($post_id)
{
  global $post;
  
  
  // verify if this is an auto save routine. If it is our form has not been submitted, so we dont want
  // to do anything
  if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) 
    return $post_id;

  
  // Check permissions
  if ( 'page' == $_POST['post_type'] ) {
    if ( !current_user_can( 'edit_page', $post_id ) )
      return $post_id;
  } else {
    if ( !current_user_can( 'edit_post', $post_id ) )
      return $post_id;
  }
  
  update_post_meta($post_id, 'asf_ad_control', $_POST['asf_suppress_ads']);
}



function asf_admin_head()
{
   ?>
  <style>
  div.message {
    background-color: pink;
    border: 1px solid #ff8080;
    border-radius: 5px;
	margin: 15px 0;
    padding: 6px 4px;
    width: 800px;
  }
   </style>
   <?php 
}

// Adds AF Theme menu to top level menu in WordPress Admin sidebar
function asf_add_main_theme_menu(){
	// Variable holds path to Adsense Flippers Menu Icon image
	$icon_url = get_bloginfo("template_url"). '/images/aftheme_icon.png'; 

	// Adds primary theme menu to Top level sidebar within WordPress Admin
	add_menu_page('IntelliTheme', 'IntelliTheme', 'administrator', 
		'af_admin', 'af_main_menu', $icon_url);
		
		function af_main_menu(){
			global $wp_version;
			?>
				<div id="intellitheme-main-menu">
				<h1>Main Menu</h1>
				<?php asf_show_updates(); ?>
				<h2>IntelliTheme</h2>
				
				<?php 
					
					if ($wp_version >= 3.4) {
						$my_theme = wp_get_theme(); echo "[ Version " . $my_theme->Version . " ]"; 
						echo '  <em>By: <a href="http://adsenseflippers.com">AdSense Flippers</a></em>';
					}
					else {
						"<p style='color: red;'>You should really upgrade your WordPress Install.</p>";
					}
				?>
				<h3>About</h3>
				<p>First off, we'd like to thank you for using IntelliTheme! We're very excited about the prospects of what the theme can deliver. 
						And, we hope you find it both profitable and easy to use! If you're not sure how to get started, check out the 
						<a href="https://intellitheme.zendesk.com/forums/21233303-documentation" >Quick Start Documentation</a>. 
						Or, if you've already got that under your belt, feel free to access our 
						<a href="https://intellitheme.zendesk.com/forums" >customer forum</a> to leave some feedback or as a question!</p>
				<h3>Data Collection</h3>
				<p>Allowing us to collect anonymous statistics from our users will help us a great deal in improving future updates to IntelliTheme. None of your
				 personal data or information is collected, only stats like CTR, pageviews/preset, etc... However, if you still don't want to contribute, just unclick the
				 box below.</p>
				<?php
					  $options = get_option('data_mining');
					  
						// set data tracking by default
						if ($options == '') {
								$name = 'data_mining';
								$value = 1;
								update_option($name, $value);
								$options = get_option('data_mining');
						}
					  
					  if ($_REQUEST['asf_collect_form'] == 1)
					  {
							if ($_REQUEST['collect'] == 'on'){
								update_option('data_mining', 1);
							} 
						
						else {
							update_option('data_mining', 2);            
						}
						
						$options = get_option('data_mining');
					  
					  }
        
        	
				?>
				 <form method="post">
          <input type="hidden" name="asf_collect_form" value="1" />
					<input type="checkbox" name="collect" <?php asf_mining_check($options); ?>
					 /> Sure, No problem!<br /><em>(Allow anonymous data collection.)</em>
					<p class="submit">
						<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
					</p>
					<!-- make save option work -->
				</form>
				
				
				</div><!-- end #intellitheme-main-menu -->
				
				<style>
					#intellitheme-main-menu {
						width: 80%;
					}
				</style>
			<?php
			
			
			// - JD debugging on 10/25/12
			//$options = get_option('preset_ad_code');
			//var_dump($options);
			
			
		}
    
	//Adds sublevel menues to main AF Theme Admin menu
	add_submenu_page('af_admin', 'Preset Selection & Ad Options', 'Preset, Design & Ad Options', 'administrator', 'preset_ad_options', 'asf_preset_ad_options');
 	add_submenu_page('af_admin', 'Google Analytics', 'Google Analytics', 'administrator', 'af_google_analytics', 'asf_ga_options');
	add_submenu_page('af_admin', 'Statistics', 'Statistics', 'administrator', 'af_statistics', 'asf_statistics_options');
}

// makes sure data collection input is marked correctly in admin area
function asf_mining_check($options) {
	if ($options == 1) {
		echo 'checked="checked"';
	}
	
	if ($options == 2) {
		echo ' ';
	}
}



function asf_prefix_ajax_save_settings()
{
  echo 'save_settings';
  // print_r($_REQUEST);
  
  // print_r($_FILES);
                    
  $args = wp_parse_args($_REQUEST['data']);
  print_r($args['preset_ad_code']);
  update_option('preset_ad_code', $args['preset_ad_code']);
  exit;
}

//Function that Provides Options within Preset Menu Page
function asf_preset_ad_options(){
  global $intellitheme_default_colors, $intellitheme_default_fonts;
   
   echo '<style type="text/css">';

   include('admin-style.php');
   
   echo '</style>';
   
    include('admin-js.php');
 
    
 
    if (isset($_POST['reset_all']))
    {
      if (wp_verify_nonce($_POST['_wpnonce'], 'reset_all'))
      {
        ?>
        <div class="wrap">
        <h2>Are you sure?</h2>
        <form method="post">
        <p>Warning: this will reset all settings to default</p>
        <?php wp_nonce_field('reset_to_default'); ?>
        <input type="submit" name="reset_all_yes" value="yes" />
        <input type="submit" name="abort" value="oops, no thanks" />
        </form>
        </div>
        <?php
        exit;
      }
    }
    ?>
    
		<div class="wrap">
			<?php echo '<img style="float: left; padding-right: 10px; " src="' . get_bloginfo('template_url') . '/images/g3433.png" />'; ?>
			<!--<div id="icon-themes" class="icon32" ><br></div> -->
			<h2>Preset Options Menu</h2>
			
			<?php
				asf_show_updates();
			?>
	
			<p>Within this menu, you can select the presets you would like to activate for rotation, and 
			you can customize their colors. Additionally, you may choose to attach different ad blocks to 
			the different 'presets'.</p>
		</div>

		
		<script type="text/javascript">
			// script is at view_preset.php
			// pass in 'current-preset' via POST method
			function viewPresetChanges(website, preset) {
				
				// post method here pass preset to script so it i set before window opens with url
					if ( jQuery.post("<?php echo get_bloginfo('template_url'); ?>/view_preset.php", { currentPreset: preset }) ) {
						window.open(website);
					}
					else {
						alert("Oops! Looks like we had a problem. Please try again.");
					}
				
			};
			
		</script>
		
    
    
		<div class="wrap">
			<p>This menu allows you to save the ad codes for individual presets. </p>
			<form class="ajaxform" method="post" action="options.php" enctype="multipart/form-data"> 
			<?PHP
				// save button
				echo '<p class="submit">';
				echo '<input type="submit" class="button-primary" value="';
				_e('Save Changes');
				echo '" />' . '</p>';
			?>
			<div id="option-notice">
				<p class="submit">
					<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
				</p>
			</div>
			<?php settings_fields( 'ad_code_hidden' ); //outputs the hidden fields to 'options.php' ?>
			<?php // settings_fields( 'preset_selection_hidden' ); //outputs the hidden fields to 'options.php' ?>
			<?php do_settings_sections( 'ad_code_inputs', 'asf_ad_code_options_main' ); //outputs the input fields, text boxes, etc... to 'options.php'?>
			
			
			</form>


      <form method="post">
      <?php wp_nonce_field('reset_all'); ?>
      <input type="submit" name="reset_all" value="<?php _e('Reset all to default') ?>" />

      </form>
		</div>
	<?php
}

// update message for when a new version of the theme is availabe. Displays in admin menu
function asf_show_updates()
{
    $current = get_site_transient('update_themes');
    $old = $current->checked['intellitheme'];
    $new = $current->response['intellitheme']['new_version'];
    
    if ( ($new > '') &&($old != $new) )
    {
      echo '<div class="message">There is a new version of Intellitheme available. Please <a href="'.admin_url('update-core.php').'">click here</a> to update to the <b>latest and most secure</b> version.</div>';
    }

}

// grabs colof options for dynamic display in CSS
function asf_hex_display($color) {
		$options = get_option('preset_ad_code');
		echo $options["$color"];
}



//function that displays preset display options
function asf_preset_display_options() {
	echo '<p>' . 'Select Your Preset' . '</p>';
}

function asf_display_preview($theme_name)
{
  echo '<p class="preview_title">Preview</p>';
  echo '<div class="preview" id="preview_'.$theme_name.'">';
  echo '<img src="'.get_stylesheet_directory_uri().'/images/' . $theme_name . '_preview.png" /> ';
  echo '</div>';
  echo '<div class="preview_image" id="preview_image_'.$theme_name.'">';
  echo '<a href="#">close</a>';
  echo '<img src="" alt="preview" />';
  echo '</div>';
}

function asf_display_radio($theme_name, &$options)
{
  echo '<div class="status_switch radio_buttons">';
  echo 'Status: ';
  if ($options[$theme_name] == 'on')
  {
    echo '<img class="status-light" src=" ' . get_bloginfo('template_url') . '/images/' . 'pre-on.png" /> ';
  } else {
    echo '<img class="status-light" src=" ' . get_bloginfo('template_url') . '/images/' . 'pre-off.png" /> ';
  }
 
  echo '<div class="on-off-radio-group">';
  echo '<input class="option-change" id="switch_on_'.$theme_name.'" type="radio" value="on" name="preset_ad_code[preset_select_option]['.$theme_name.']"';
  if ($options[$theme_name] == 'on')
  {
    echo ' checked ';
  }
  echo ' /><label class="radio-label" for="switch_on_'.$theme_name.'">on</label>';
  echo '<input class="option-change" id="switch_off_'.$theme_name.'" type="radio" value="off" name="preset_ad_code[preset_select_option]['.$theme_name.']"';
  if ($options[$theme_name] != 'on')
  {
    echo ' checked '; 
  }
  echo ' /><label class="radio-label" for="switch_off_'.$theme_name.'">off</label>';
  // echo '<div class="set-directions">After selecting \'on/off\', click the <strong>\'Set\'</strong> button above</div>';
  echo '</div>';
  echo '</div><!-- end .on-off-radio-group -->';
}

function asf_display_weight($theme_name, &$weights, &$weight_locks)
{
  if ($weights[$theme_name] == '')
  {
    $value = 10;
  } else {
    $value = $weights[$theme_name];
  }
  
  $local_path = get_stylesheet_directory_uri();
  echo '<div class="weight" id="weight_'.$theme_name.'">';
  // echo '<div class="lock" id="lock_weight_'.$theme_name.'"></div>';
  // echo '<input type="hidden" id="valuelock_weight_'.$theme_name.'" name="preset_ad_code[preset_weight_lock]['.$theme_name.']" value="'.$weight_locks[$theme_name].'" />';
  echo '<b>Display Frequency:</b><br />';
  echo '<span class="left">Less Often</span><span class="middle">Normal</span><span class="right">More Often</span><br />';
  echo '<div class="slider" id="slider_'.$theme_name.'"></div>';
  echo '<input type="hidden" id="slider_'.$theme_name.'_field" name="preset_ad_code[preset_weight_option]['.$theme_name.']" value="'. $value . '" />';
  echo "<div class='center-mark'><img src='$local_path/images/center-mark.png' /></div>";

  
  echo '</div>';
}

//Registers the settings for the preset & Ad Options menu page into a wp settings field
add_action('admin_init', 'asf_ad_options_setup_init');

function asf_ad_options_setup_init() {
  if (isset($_GET['action']) and  $_GET['action'] == 'download')
  {
    $file = dirname(__FILE__) . '/export.csv';
  	if (file_exists($file))
  	{
  		$len = filesize($file);
  		header('content-type: x-application/csv');
  		header('content-length: '.$len);
  		header('content-disposition: attachment; filename='.basename($file));
  		$fp=fopen($file, 'rb');
  		fpassthru($fp);
  		exit;
  	} else {
      echo 'file not found: ' . $file;
    }

  }

	register_setting('ad_code_hidden', 'preset_ad_code','asf_ad_options_sanitization');
	add_settings_section('ad_options_main', 'Preset Ad Options Menus', 'asf_ad_display_options', 'ad_code_inputs');

}


// outlines function to display correct background color within each menu (on = green | off = red)
function asf_display_background_color($input) {
		
		if ($input == 'on') {
			echo 'active';
		}
		
		else {
			echo 'inactive';
		}
		
}


function asf_ad_display_options() {

	$options = get_option('preset_ad_code');
	
	echo '<div class="preset_wrapper">';
	asf_preset_box(PresetName::TOWER_RIGHT, 'Tower Right', $options, 'W: 950px - H: 88px' );
	asf_preset_box(PresetName::TOWER_LEFT, 'Tower Left', $options, 'W: 950px - H: 88px');
	asf_preset_box(PresetName::CENTRAL_BANK, 'Central Bank', $options, 'W: 927px - H: 180px');
	asf_preset_box(PresetName::EASTSIDE, 'EastSide', $options, 'W: 1000px - H: 175px');
	asf_preset_box(PresetName::SANDLOT, 'Sandlot', $options, 'W: 950px - H: 80px');
	echo '</div>';
}


function asf_output_styles()
{
	$options = get_option('preset_ad_code');
	$preset = $_SESSION['asf_current_preset'];
  $rules = '';
  
   // Header Image
  if ($options[$preset.'_header_image'] > '')
  {
    $rules .= '#header { background-image: url(' . $options[$preset.'_header_image'] . '); background-repeat: no-repeat; }';
    $rules .= "\r\n";
  }
  
  
  // Fonts
  
  // h1 font styles
    if ($options[$preset.'_h1_font'] > '')
  {
    $rules .= 'h1, h1 a:link, h1 a:visited, h1 a:hover { font-family: ' . $options[$preset.'_h1_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
   if ($options[$preset.'_h1_font_size'] > '')
  {
    $rules .= 'h1, h1 a:link, h1 a:visited, h1 a:hover { font-size: ' . $options[$preset.'_h1_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
  // h2 font styles
    if ($options[$preset.'_page_h2_font'] > '' && !is_single() )
  {
    $rules .= '#content h2 a:link, #content h2 a:visited, #content h2 a:hover { font-family: ' . $options[$preset.'_page_h2_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
   if ($options[$preset.'_page_h2_font_size'] > '' && !is_single() )
  {
    $rules .= '#content h2 a:link, #content h2 a:visited, #content h2 a:hover { font-size: ' . $options[$preset.'_page_h2_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
      if ($options[$preset.'_post_h2_font'] > '' && is_single() )
  {
    $rules .= '#content h2 { font-family: ' . $options[$preset.'_post_h2_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
   if ($options[$preset.'_post_h2_font_size'] > '' && is_single() )
  {
    $rules .= '#content h2 { font-size: ' . $options[$preset.'_post_h2_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
   // h3 font styles
    if ($options[$preset.'_h3_font'] > '')
  {
    $rules .= 'h3, h3 a:link, h3 a:visited, h3 a:hover { font-family: ' . $options[$preset.'_h3_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
   if ($options[$preset.'_h3_font_size'] > '')
  {
    $rules .= 'h3, h3 a:link, h3 a:visited, h3 a:hover { font-size: ' . $options[$preset.'_h3_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
  // content font styles
    if ($options[$preset.'_content_font'] > '')
  {
    $rules .= '.post p, .page p, #sidebar p, .sidebar_left p, .sidebar_right p { font-family: ' . $options[$preset.'_content_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
   if ($options[$preset.'_content_font_size'] > '')
  {
    $rules .= '.post p, #sidebar p, p a:link, p a:visited, p a:hover { font-size: ' . $options[$preset.'_content_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
  // link font styles
   if ($options[$preset.'_link_font'] > '')
  {
    $rules .= '.post a:link, .post a:visited, .post a:hover, #sidebar a:link, #sidebar a:visited, #sidebar a:hover { font-family: ' . $options[$preset.'_link_font'] . ' !important; }';
    $rules .= "\r\n";
  }
  
  
   if ($options[$preset.'_link_font_size'] > '')
  {
    $rules .= '#sidebar a:link, 
					#sidebar a:visited, 
					#sidebar a:hover, 
					.sidebar_right a:link,
					.sidebar_right a:visited,
					.sidebar_right a:hover,
					.sidebar_left a:link,
					.sidebar_left a:visited,
					.sidebar_left a:hover { font-size: ' . $options[$preset.'_link_font_size'] . 'px' . ' !important; }';
    $rules .= "\r\n";
  }
  
  
  
  // Colors
  if ($options[$preset.'_color_background'] > '')
  {
    $rules .= 'body { background-color: ' . $options[$preset.'_color_background'] . ' !important; }';
    $rules .= "\r\n";
  }
  
  if ($options[$preset.'_color_header'] > '')
  {
    $rules .= '#header { background-color: ' . $options[$preset.'_color_header'] . ' !important; }';
    $rules .= "\r\n";
  }
  
  
  if ($options[$preset.'_color_sidebar_left'] > '')
  {
    $rules .= '.sidebar_left { background-color: ' . $options[$preset.'_color_sidebar_left'] . ' !important; }';
    $rules .= "\r\n";
  }
  
  if ($options[$preset.'_color_sidebar_right'] > '')
  {
    $rules .= '.sidebar_right { background-color: ' . $options[$preset.'_color_sidebar_right'] . ' !important; }';
    $rules .= "\r\n";
  }
  
  if ($options[$preset.'_color_sidebar'] > '')
  {
		$rules .= '#sidebar { background-color: ' . $options[$preset.'_color_sidebar'] . ' !important; }';
		$rules .= "\r\n";
  
  }

  if ($options[$preset.'_color_links'] > '')
  {
    $rules .= '#sidebar a, #sidebar a:link, #content a:link, #content a:visited, #content a:hover { color: ' . $options[$preset.'_color_links'] . ' !important; }';    
    $rules .= "\r\n";
  }
  
  if ($options[$preset.'_color_footer'] > '')
  {
    $rules .= '#footer { background-color: ' . $options[$preset.'_color_footer'] . '; }';    
    $rules .= "\r\n";
  }
  
  
echo '<style type="text/css">';
echo $rules;
echo '</style>';
}



function asf_preset_box($theme_name, $title, &$options, $header_size){
	$select_options = $options['preset_select_option'];
	$weight_options = $options['preset_weight_option'];
	$weight_locks = $options['preset_weight_lock'];
	$theme_url = get_bloginfo('template_url');
	$upload_dir = wp_upload_dir();
	
	echo '<div class="menu_box '; // Make sure there is a space after 'menu_box', or the admin menu breaks
	asf_display_background_color($select_options[$theme_name]);
	echo '">';
	echo '<h2>'.$title.' Preset Options</h2>';
	asf_display_weight($theme_name, $weight_options, $weight_locks);
	asf_display_radio($theme_name, $select_options);
	asf_display_preview($theme_name);
	echo '<div class="preset-changes-preview">';
	echo "<p><a onclick=\"viewPresetChanges(" . '\'' . site_url() . '\'' . ", '{$theme_name}')\" href='' >View Changes</a></p>";
	echo '</div><!-- end .preset-changes-preview -->';
	echo '<div class="expandable" ';
	  if ($options[$theme_name . '_indicator'] == 'visible')
	  {
		echo 'style="display: block;"';
	  } else {
		echo 'style="display: none;"';
	  }
	  echo '>';

	echo '<div class="design_options_area">';
  
	echo '<input class="indicator" type="hidden" name="preset_ad_code['.$theme_name.'_indicator]" value="'.$options[$theme_name . '_indicator'].'" />';
  
	echo '<h3>Preset Design Options</h3>';
	echo '<p>Below you can adjust and customize the design options for this preset. Style each preset to your own
		specifications by choose your own colors, fonts, and header image. If you are unhappy with the results, simply use the button below to reset
		to the default settings.</p>';
	// reset button
	echo '<button id="reset_'.$theme_name.'" type="button" class="reset-colors">Reset to Default</button>';
  
  if ( $theme_name !== PresetName::SANDLOT ) { 
		echo '<h4>Header Image</h4>';
		echo '<p>You may change the header image for this file by uploading a new one.</p>';
		echo "<p>Appropriate image size is <b>{$header_size}</b><em>(Note: The header image sizes change for each preset)</em></p>";
		echo "<input class='option-change' type='file' name='header_images[{$theme_name}]' />";
	  
		  if ($options[$theme_name . '_header_image'] > '')
		  {
			echo '<div class="img_preview"><img src="' . $options[$theme_name . '_header_image'] . '" alt="header image preview" /></div>';
			echo '<input type="submit" 
			  name="delete['.$theme_name . '_header_image'.']" 
			  value="Delete Image" />';
		  } else {
			// show nothing;
		}
  
	}
  
  echo '<div class="color_admin_area">';
  echo '<h4>Colors</h4>';
  echo '<div class="color-input-wrap">';
  echo "<div id='color_display_bg_{$theme_name}'></div>Background: <input type='text' id='link-color' class='color_picker option-change' 
    name='preset_ad_code[{$theme_name}_color_background]'
    value='{$options[$theme_name . '_color_background']}' />
    <br />";
	echo '</div><!-- end .color-input-wrap -->';
	
	echo '<div class="color-input-wrap">';
  echo "<div id='color_display_header_{$theme_name}'></div>Header: <input type='text' class='color_picker option-change' 
    name='preset_ad_code[{$theme_name}_color_header]'
    value='{$options[$theme_name . '_color_header']}' /><br />";
	echo '</div><!-- end .color-input-wrap -->';
	
	
	// Only display for Tower Right and left
	if ( ($theme_name == PresetName::TOWER_RIGHT) || ($theme_name == PresetName::TOWER_LEFT) ) {
		echo '<div class="color-input-wrap">';
		echo "<div id='color_display_side_left_{$theme_name}'></div>Inner Sidebar: <input type='text' class='color_picker option-change' 
		name='preset_ad_code[{$theme_name}_color_sidebar_left]'
		value='{$options[$theme_name . '_color_sidebar_left']}' /><br />";
		echo '</div><!-- end .color-input-wrap -->';
	
	echo '<div class="color-input-wrap">';
	  echo "<div id='color_display_side_right_{$theme_name}'></div>Outer Sidebar: <input type='text' class='color_picker option-change' 
		name='preset_ad_code[{$theme_name}_color_sidebar_right]'
		value='{$options[$theme_name . '_color_sidebar_right']}' /><br />";
		echo '</div><!-- end .color-input-wrap -->';
		
	}
	
	
	
	echo '<div class="color-input-wrap">';
  echo "<div id='color_display_links_{$theme_name}'></div>Links: <input type='text' class='color_picker option-change' 
    name='preset_ad_code[{$theme_name}_color_links]'
    value='{$options[$theme_name . '_color_links']}' /><br />";
	echo '</div><!-- end .color-input-wrap -->';
	
	// colors for footers
	echo '<div class="color-input-wrap">';
	echo "<div id='color_display_footer_{$theme_name}'></div>Footer: <input type='text' class='color_picker option-change' 
		name='preset_ad_code[{$theme_name}_color_footer]'
		value='{$options[$theme_name . '_color_footer']}' /><br />";
	echo '</div><!-- end .color-input-wrap -->';
	

	echo '</div><!-- end .color_admin_area -->';
	
	// custom font options for each preset
	echo '<div class="font_choice_area" >';
	
	echo '<h4>Fonts</h4>';
	
	//  array holds names, and db names for adding custom font options to each preset
	$font_option_settings = array(
	
		'Custom Font Setting 1' => array(
			'option-title' => 'Site/Blog Title - <em>h1 tag</em>',
			'postfix-font-db-option-name' => '_h1_font',
			'postfix-size-db-option-name' => '_h1_font_size'
		),
		
		'Custom Font Setting 2' => array(
			'option-title' => 'Page Titles - <em>Page h2 tag</em>',
			'postfix-font-db-option-name' => '_page_h2_font',
			'postfix-size-db-option-name' => '_page_h2_font_size'
		),
		
		'Custom Font Setting 3' => array(
			'option-title' => 'Post Titles - <em>Post h2 tag</em>',
			'postfix-font-db-option-name' => '_post_h2_font',
			'postfix-size-db-option-name' => '_post_h2_font_size'
		),
		
		'Custom Font Setting 4' => array(
			'option-title' => 'Sidebar Headings - <em>h3 tag</em>',
			'postfix-font-db-option-name' => '_h3_font',
			'postfix-size-db-option-name' => '_h3_font_size'
		),
		
		'Custom Font Setting 5' => array(
			'option-title' => 'Content - <em>paragraph tags</em>',
			'postfix-font-db-option-name' => '_content_font',
			'postfix-size-db-option-name' => '_content_font_size'
		),
		
		'Custom Font Setting 6' => array(
			'option-title' => 'Links - <em>page & sidebar links</em>',
			'postfix-font-db-option-name' => '_link_font',
			'postfix-size-db-option-name' => '_link_font_size'
		)
		
	);
	
	//Option order - $options, $theme_name, $TITLE, FONT_OPTION_NAME, SIZE_OPTION_NAME
	foreach ($font_option_settings as $font_option) {
		asf_custom_fonts($options, $theme_name, $font_option['option-title'], $font_option['postfix-font-db-option-name'], $font_option['postfix-size-db-option-name']);
	}
	


	echo '</div><!-- end .font_choice_area -->';
	
	// toggle display of blog title and description
	echo '<div class="title_display_option_area">';
	echo '<h4>Site Title/Description Display Toggle</h4>';
	echo '<p>Turning this option to <b>"off"</b> will remove the title and description from your site header. 
					However, the code will still be output for SEO purposes. This is particularly useful if you\'re using a custom header image.</p>';
	
	$site_description = $options[$theme_name . '_description_toggle'] ;
	
	if ( !$site_description || $site_description == 'on' ) {
		echo '<p><b style="color:green;">On</b> - Your Site Title an Description are currently showing for this preset.</p>';
		$title_on_checked = "checked='checked' ";
		$title_off_checked = ' ';
	}
	else {
		echo '<p><b style="color:red;">Off</b> - Your Site\'s Title and Description are NOT currently displaying for this preset.</p>';
		$title_on_checked = ' ';
		$title_off_checked = "checked='checked' ";
	}	
					
	echo "<input id=' ' class='option-change' type='radio' value='on' name='preset_ad_code[{$theme_name}_description_toggle]' {$title_on_checked} >On</input>";
	echo "<input id=' ' class='option-change' type='radio' value='off' name='preset_ad_code[{$theme_name}_description_toggle]' {$title_off_checked} >Off</input>";
	
	
	
	echo '</div><!-- end .title_display_option_area -->';
	
	
	// toggle Google Image Lightbox Breaking Function
	echo '<div class="g_image_break_option_area">';
	echo '<h4>Remove Google Image Lightbox</h4>';
	echo '<p>If this option is turned on, visitors who find your site through Google Images will be redirected directly to your site, instead of seeing 
	the lightbox display of the image they clicked on.</p>';
	
	$g_image_break = $options[$theme_name . '_g_image_break'] ;
	
	if ( !$g_image_break || $g_image_break == 'on' ) {
		echo '<p><b style="color:green;">On</b> - Your site is displaying directly from within Google Images.</p>';
		$g_on_checked = "checked='checked' ";
		$g_off_checked = ' ';
	}
	else {
		echo '<p><b style="color:red;">Off</b> - Your Site\'s is not adjusting the Google Image lightbox.</p>';
		$g_on_checked = ' ';
		$g_off_checked = "checked='checked' ";
	}	
					
	echo "<input id=' ' class='option-change' type='radio' value='on' name='preset_ad_code[{$theme_name}_g_image_break]' {$g_on_checked} >On</input>";
	echo "<input id=' ' class='option-change' type='radio' value='off' name='preset_ad_code[{$theme_name}_g_image_break]' {$g_off_checked} >Off</input>";
	
	
	
	echo '</div><!-- end .g_image_beak_option_area -->';
	
	
	
	
	
	echo '</div><!-- end .design_options_area -->';
  
	/* 
	 * Notes for adding more code boxes for new presets below.
	 *  Ad codes take the following parameters.
	 *		asf_ad_code_save_box( $options, "TITLE ABOVE AD", "NAME OF DB OPTION", "NAME OF IMAGE', $theme_url);
	 */
	 
	// Tower Right Codes 
	echo '<h3>Ad Code Options</h3>';
		
	if ($theme_name == PresetName::EASTSIDE) {
		echo '<span style="color: red">AdSense Terms of service only allows for three "Ads For Content" on a single page. This preset allows for up to six. 
				However, you should only use three at any given time. Placing more ad units on your pages is risky, and could result in having your AdSense
				account banned. <a href="https://support.google.com/adsense/bin/answer.py?hl=en-GB&answer=1346295&topic=1271508&rd=1#Google_ad_limit_per_page" target="_blank" >[Read More]</a></span>';
	}
	
	// holds all arrays for individual preset ad units and settings
	include('ad_settings.php');
	
	switch ($theme_name) {
		
		// Tower Right Ad Codes
		case PresetName::TOWER_RIGHT:
			$ad_setting =  $tower_right_ad_block_setting;
			break;
	
		// Tower Left Codes
		case PresetName::TOWER_LEFT:
			$ad_setting = $tower_left_ad_block_setting;
			break;
	
		// Central Bank Ad Codes
		case PresetName::CENTRAL_BANK:
			$ad_setting = $central_bank_ad_block_setting;
			break;
	
		// EastSide Ad Codes
		case PresetName::EASTSIDE:
			$ad_setting = $eastside_ad_block_setting;
			break;
	
		// Sandlot Ad Codes
		case PresetName::SANDLOT:
			$ad_setting = $sandlot_ad_block_setting;
			break;
		
	
	} // end switch
	
	
	// run through ad setting loops and setup options in the correct preset menu
	 foreach ($ad_setting as $individual_ad) {
		// function displays the ad option output for each ad
		asf_ad_code_save_box($options, $individual_ad['title'], $individual_ad['option_name'], $individual_ad['image_name'], $theme_url );
	}
	
	
	echo '<div style="clear:both"></div>';
	echo '</div>';
	echo '</div>';
}


function asf_ad_code_save_box($options, $title, $ad_option_name, $image_name, $theme_url) {
	echo "<div class='ad_code_options_wrapper'>";
	echo "<h4>$title</h4>";
	echo "<textarea rows='10' cols='60' wrap='physical' class='option-change' name='preset_ad_code[$ad_option_name]' style='color: grey;' onclick='this.focus();this.select()' >$options[$ad_option_name]</textarea>";
	echo "<img class='ad-image' src='$theme_url/images/$image_name' />";
	echo "</div><!-- end .ad_code_options_wrapper -->";
}

function asf_custom_fonts($options, $theme_name, $title, $font_option, $size_option) {
	$preset = $theme_name;
	$font_db_option = $preset .= $font_option;
	echo '<div class="font-wrapper" >';
	echo '<div class="font-option" >';
		echo "$title: <select class='option-change' name='preset_ad_code[{$font_db_option}]' style=' width:80px;' >";
		

		$font = array( 
			'Verdana' => 'Verdana', 
			'Arial' => 'Arial', 
			'Times' => 'Times', 
			'Georgia' => 'Georgia', 
			'Lucida Grande' => ' "Lucida Grande", "Lucida Sans Unicode", "Lucida Sans" ',
			'Helvetica' => 'Helvetica, Arial, Sans-Serif'
			);
			
			foreach ($font as $key => $value) {
				if ($options[$font_db_option] == $value ) {
					$selected = "selected='selected' ";
				}
				else {
					$selected = ' ';
				}
					echo "<option value='$value' $selected >$key</option>";
					
		}
		
		echo "</select>";
		echo '</div><!-- end .font-option -->';
		
		
		// font size
		$preset = $theme_name;
		$size_db_option = $preset .= $size_option;
		
		echo '<div class="font-option" >';
		echo "Size: <select class='option-change' name='preset_ad_code[{$size_db_option}]' style=' width:50px;' > ";
			
			$sizes = array( 10, 12, 13, 14, 15, 16, 17, 18, 20, 22, 24, 28, 30, 32, 36, 42, 48);
			
			foreach ($sizes as $num) {
				if ($options[$size_db_option] == $num ) {
					$selected = "selected='selected' ";
				}
				else {
					$selected = ' ';
				}
				echo "<option value='$num' $selected >$num </option>";
			}
			
		echo '</select>';
		echo '</div><!-- end .font-option -->';
		
		
		echo '<div style="clear:both"></div>';
		
		echo '</div><!-- end .font-wrapper -->';
		// temp feedback
		//var_dump( $options[$theme_name . '_h2_font_size'] );
}




// sanitizes the inputs from the ad code admin menu
function asf_ad_options_sanitization($input) {
  
  // $upload_dir = wp_upload_dir();
  
  $file_ary = array();
  
  if (isset($_FILES['header_images']))
  {
    foreach($_FILES['header_images'] as $files_element => $f)
    {
      foreach ($f as $k => $i)
      {
        $file_ary[$k][$files_element] = $i;  
      }
    }
  }
  
  // pre-fill input field with old header images
	$options = get_option('preset_ad_code');
  
  foreach($file_ary as $theme => $file)
  {
    // $filename = $theme . '_header_image' . substr($file['name'], strpos($file['name'], '.'));
    // $input['preset_ad_code'][$theme . '_header_image'] = $filename;

    if ($file['name'] > '')
    {
      $overrides = array('test_form' => false);
      $file = wp_handle_upload($file, $overrides);
  
  		if(!array_key_exists('error',$file))
      {
  			$input[$theme . '_header_image'] = $file['url'];
      }
    } else {
      if ($_POST['delete'][$theme . '_header_image'] > '')
      {
        // don't store image
      } else {
        // store old value instead
        $input[$theme . '_header_image'] = $options[$theme . '_header_image'];
      }
    }
    
    // move_uploaded_file($file['tmp_name'], $upload_dir['basedir'] . '/' . $filename);
  }
  
  
	// ensures that user is admin and has permission to save options to database
	if (current_user_can('administrator')) {
		
		// filters for dangerous html
		//wp_filter_post_kses($input); // <-- was causing error on some installs
		return $input;
	} // end if
	
}




// Function that Provides Options within Google Analytics Menu Page
function asf_ga_options(){
	?>
		<div class="wrap">
			<div id="icon-themes" class="icon32" ><br></div>
			<h2>Google Analytics Code</h2>
			<p>Input your unique Google Analytics code for this site and then click 'save'. The code should be
			something like, <strong>'UA-33425465-45'</strong>. If you need help finding this code, go here.</p>
      <?php asf_show_updates() ?>
			<form method="post" action="options.php"> 
			<?php settings_fields( 'google_analytics_hidden' ); //outputs the hidden fields to 'options.php' ?>
			<?php do_settings_sections( 'google_analytics_inputs', 'af_google_analytics_options_main' ); //outputs the input fields, text boxes, etc... to 'options.php'?>
			
				<p class="submit">
					<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
				</p>
			</form>

		</div>
	<?php
}


//Registers the settings for the preset & Design Options menu page into a wp settings field
add_action('admin_init', 'asf_google_analytics_options_init');

function asf_google_analytics_options_init() {
	register_setting('google_analytics_hidden', 'analytics_code_option');
	add_settings_section('google_analytics_option_main', 'Google Analytics Code', 'asf_google_analytics_options', 'google_analytics_inputs');
	add_settings_field('google_analytics_options_display', 'Unique Analytics Identifier', 
		'asf_display_google_analytics_options', 'google_analytics_inputs', 'google_analytics_option_main');
}

//function that displays details about google analytics display options
function asf_google_analytics_options() {
	echo '<p>' . 'Input your Google Analytics Code:' . '</p>';
}


// displays actual output for google analytics settings menu
function asf_display_google_analytics_options(){
	
	echo "<p><strong>Input:</strong>";
	echo "<br/>";
	echo "<input type='text' size='35' name='analytics_code_option' style='background-color: #ededed;' /><br/>";
	
	$options = get_option('analytics_code_option');
	
	// user feedback
	if ($options != NUll && $options != '') {
		echo "Your current Analytics code is set to: " . "<strong>" . "$options" . "</strong>";
	}
	
	else {
		echo "<span style='color: red;'>";
		echo "Hey! Google Analytics is not tracking your website. Set your unique code above.";
		echo "</span>";
	}
			
}


// function outputs google analytics code with custom unique identifier
function asf_output_analytics_code() {
	
	$analyticsCode = get_option('analytics_code_option');
	
	If ($analyticsCode != Null && $analyticsCode != '' ) {
		?>
		
			<script type="text/javascript">

				var _gaq = _gaq || [];
				_gaq.push(['_setAccount', '<?php echo $analyticsCode; ?>']);
				_gaq.push(['_trackPageview']);

				(function() {
					var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
					ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
					var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
				})();

			</script>
		
		
		<?php
		
	
	}

}




function asf_get_theme_name($shortname)
{
  $names = array(
	PresetName::TOWER_RIGHT => 'Tower Right',
	PresetName::TOWER_LEFT => 'Tower Left',
	PresetName::CENTRAL_BANK => 'Central Bank',
	PresetName::EASTSIDE => 'EastSide',
	PresetName::SANDLOT => 'Sandlot',
  );
  
  return $names[$shortname];
}

//Function that Provides Options within the Statistics Page
function asf_statistics_options(){

  global $wpdb;
	$options = get_option('preset_ad_code');
	$select_options = $options['preset_select_option'];
  
  $this_url = is_ssl() ? 'https://' : 'http://' . 
    $_SERVER['HTTP_HOST'] . '/' . $_SERVER['REQUEST_URI'];
  
  if (isset($_POST['export_csv']))
  {
    if (wp_verify_nonce($_POST['_wpnonce'], 'save_statistics'))
    {
      $export_file = dirname(__FILE__) . '/export.csv';
      $fp_export = fopen($export_file, 'w');
      if (!$fp_export)
      {
        echo 'Cannot open file: ' . $export_file;
      } else {
        // echo 'export to: ' . $export_file;
        fputs($fp_export, 'Preset,Status,Pageviews,Clicks,CTR,Accuracy'."\r\n");
      } 
    } else {
      echo 'nonce error';
    }   
  }

  if (isset($_POST['reset_stats']))
  {
    if (wp_verify_nonce($_POST['_wpnonce'],'save_statistics'))
    {
      ?>
      <form action="" method="post">
      <?php wp_nonce_field('clear_statistics'); ?>

      <div style=" background-color: pink; padding: 3px 14px; margin: 14px  14px 14px 3px; border: 1px solid #ffaaaa; border-radius: 5px;" >
	  <p><b>All of the data that IntelliTheme has stored with be erased. You will not be able to retrieve it again.</b></p>
	  <p>Do you really want to clear all stats?</p>
	  </div>
	  
      <button type="submit" name="clear_yes" value="yes" />yes</button>
      <button type="submit" name="clear_no" value="no" />no</button>
      </form>
      <?php
    } else {
      echo 'nonce error';
    }
  }
  if (isset($_POST['clear_yes']))
  {
    if (wp_verify_nonce($_POST['_wpnonce'],'clear_statistics'))
    {
      $sql = "delete from {$wpdb->prefix}tracking";
      $wpdb->query($sql);
      echo 'All Stats cleared';
    }
  }
  
  
  // Set all statistics to display via PST
  date_default_timezone_set('America/Los_Angeles');
  
  $stats_from = strtotime('2012-01-01');
  $stats_to = time() + (3600 * 19);
  
  // we don't want to include any statstics from the current day unless All-Time is selected.
  // dynamically grab the hours since the start of the day
  // $difference can now be subtracted from the current time.
  $now = time();
  $count_hours = date('G', $now);
  $count_minutes = date('i', $now);
  $difference = (($count_hours * 3600) + ($count_minutes * 60));
  
  if (isset($_POST['fetch_days']))
  {
    $stats_from = strtotime($_POST['stats_from']);
    $stats_to = strtotime($_POST['stats_to']);
  }
 
  
  if (isset($_POST['time']))
  {
    switch ($_POST['time'])
    {
      case 'All Time':
        $stats_from = strtotime('2012-01-01');
        $stats_to = time() + (3600 * 19);
        break;
      case 'Last 30 Days':
        $stats_from = time() - ((3600*24*30) + $difference);
        $stats_to = time() - ($difference + 60);
        break;
      case 'Last 60 Days':
        $stats_from = time() - ((3600*24*60) + $difference);
        $stats_to = time() - ($difference+ 60);
        break;
      case 'Last 7 Days':
        $stats_from = time() - ((3600*24*7) + $difference);
        $stats_to = time() - ($difference +60);
        break;
    }
  }

  $_POST['stats_from'] = date('m/d/Y', $stats_from);
  $_POST['stats_to'] = date('m/d/Y', $stats_to);
  
  ?>
  <style type="text/css">
  
 div#table_stats table {
    border-bottom: 10px solid #808080; 
  }
  
  div#table_stats table th {
    background: #666;
    color: #FFF;
    padding: 5px 15px;
    vertical-align: top;
  }
  div#table_stats table th.first {
    background: #666;
    border-radius: 15px 0 0 0;
    -moz-border-radius: 15px 0 0 0;
    -webkit-border-radius: 15px 0 0 0;
    -ms-border-radius: 15px 0 0 0;
    -o-border-radius: 15px 0 0 0;
  }
  div#table_stats table th.last {
    background: #666;
    border-radius: 0 15px 0 0;
    -moz-border-radius: 0 15px 0 0;
    -webkit-border-radius: 0 15px 0 0;
    -ms-border-radius: 0 15px 0 0;
    -o-border-radius: 0 15px 0 0;
    padding-right: 60px;
  }
  div#table_stats table th > span {
    display: block;
    font-size: 9px;
  }  

  div#table_stats table td {
    padding: 5px;
    padding-right: 25px;
    text-align: right;
    font-size: 14px;
  }
  div#table_stats table td.left {
    text-align: left;
  }
  
  div#table_stats table tr:nth-child(odd) {
    background: #EEE;
  }
  div#table_stats table tr:nth-child(1) {
    background: none;
  }
  
  div#tile_stats > div { 
    float: left; 
    width: 200px; 
    border: 1px solid #DDD; 
    margin-right: 30px;
    margin-bottom: 30px;
    padding: 20px;
    background: #eaeaea;
    border-radius: 30px;
    -moz-border-radius: 30px;
    -webkit-border-radius: 30px;
    -ms-border-radius: 30px;
    -o-border-radius: 30px;
  }
  
  div.off {
    color: #999;
  }
  
  p.fullcolor { color: #000; }
  
  span.off {
    color: red;
    font-size: 14px;
  }
  
  span.on {
    color: green;
    font-size: 14px;
  }
  
  </style>
  
  <script type="text/javascript">
  jQuery(document).ready(function(){
    jQuery('div#tile_stats').css('display', 'none');
    jQuery('div#table_stats').css('display', 'none');
    if (jQuery('#stats_setting').val() == 'tile')
    {
      jQuery('div#tile_stats').fadeIn('slow');
    } else {
      jQuery('div#table_stats').fadeIn('slow');    
    }
    jQuery('#switch_tile').on('click', function(event){
      jQuery('div#table_stats').fadeOut('fast', function(){
        jQuery('div#tile_stats').fadeIn('slow');
        jQuery('#stats_setting').val('tile');
      });
    });
    jQuery('#switch_table').on('click', function(event){
      jQuery('div#tile_stats').fadeOut('fast', function(){
        jQuery('div#table_stats').fadeIn('slow');
        jQuery('#stats_setting').val('table');
      });
    });
    
    jQuery('.datepicker').datepicker();
    
  });
  </script>
  <h1>Statistics Dashboard</h1>
  <?php asf_show_updates() ?>
  <form action="" method="post">
  <p>Select Statistics Display Time Period:</p>
  <p><em>All statistics are tracked and displayed in Pacific Standard Time(PST), which is currently:</em><b> <?php echo gmdate('H:i \o\n l F j, Y', time()-25200); ?></b></p> 
  <p>
  <button type="submit" name="time" value="All Time" />All Time</button>
  <button type="submit" name="time" value="Last 7 Days" />Last 7 Days</button>
  <button type="submit" name="time" value="Last 30 Days" />Last 30 Days</button>
  <button type="submit" name="time" value="Last 60 Days" />Last 60 Days</button>
  <input type="hidden" id="stats_setting" name="stats_setting" value="<?php echo $_POST['stats_setting'] ?>" />
  </p>
  <p>From <input type="text" class="datepicker" name="stats_from" value=<?php echo $_POST['stats_from']  ?> />
  To: <input type="text" class="datepicker" name="stats_to" value=<?php echo $_POST['stats_to']  ?> /> <button type="submit" name="fetch_days" value="show" />show</button> </p>
	
  <p>
  Display: <button id="switch_tile" type="button" name="switch_tile" value="Tile" />Tile</button>
  <button id="switch_table" type="button" name="switch_table" value="Table" />Table</button></p>
  
  <div id="table_stats">
  <?php
  $sql = "select sum( if(clicked='no',1,0) ) as views, 
    sum( if(clicked='yes',1,0) ) as clicks, 
    theme from {$wpdb->prefix}tracking 
    where created between '".
    date('Y-m-d', $stats_from).
    "' and '".
    date('Y-m-d', $stats_to).
    "' group by theme";
  $result = $wpdb->get_results($sql);
  echo '<table border="0" cellpadding="0" cellspacing="0">';
  echo '<tr><th class="first">Preset</th><th>Current<br/>Status</th><th>Pageviews</th><th>Clicks</th><th>CTR<span>(Click Through Rate)</span></th><th class="last">Accuracy</th></tr>';
  foreach ($result as $r)
  {
    echo '<tr><td class="left">';
    echo asf_get_theme_name($r->theme);
    echo '</td><td>';
    echo '<span class="'.$select_options[$r->theme].'">';
    echo ucwords($select_options[$r->theme]);
    echo '</span>';
    echo '</td><td>';
    echo (int)$r->views;
    echo '</td><td>';
    echo $r->clicks;
    echo '</td><td>';
    if((int)$r->views > 0){
      echo round((int)$r->clicks / (int)$r->views * 100.0, 2) . '%';
    } else {
      echo 'n/a';
    } 
    echo '</td><td>';
    echo '&nbsp;';
    echo '</td></tr>';

    if (isset($_POST['export_csv']))
    {
      if (wp_verify_nonce($_POST['_wpnonce'], 'save_statistics'))
      {
        $export_line = asf_get_theme_name($r->theme) . ',' .
          ucwords($select_options[$r->theme]) . ','.
          (int)$r->views . ',' .
          $r->clicks . ',';
        if((int)$r->views > 0){
          $export_line .= round((int)$r->clicks / (int)$r->views * 100.0, 2) . '%';
        } else {
          $export_line .= 'n/a';
        } 
        $export_line .= ',' . ' ' . "\r\n";
      
        fputs($fp_export, $export_line);
      } else {
        echo 'nonce error';
      }
    }
  }
  echo '</table>';
  ?>
  </div>
  <div id="tile_stats">
  <?php
  foreach ($result as $r)
  {
    echo '<div class="'.$select_options[$r->theme].'">';
    echo '<h2>' . asf_get_theme_name($r->theme) . '</h2>';
    echo '<p class="fullcolor">Current Status: ';
    echo '<span class="'.$select_options[$r->theme].'">';
    echo ucwords($select_options[$r->theme]);
    echo '</span></p>';
    echo '<p>Page Views: ' . (int)$r->views . '</p>';
    echo '<p>Clicks: ' . $r->clicks . '</p>';
    echo '<p>CTR: ';
    if((int)$r->views > 0){
      echo round((int)$r->clicks / (int)$r->views * 100.0, 2) . '%';
    } else {
      echo 'n/a';
    } 
    echo ' <span>(Accuracy: ' . ')</span>';
    echo '</div>';
  }
  ?>
  </div>
  <input type="submit" value="export csv" name="export_csv" />
  <?php
  if (isset($_POST['export_csv']))
  {
    fclose($fp_export);
    echo '<a href="'.$_SERVER['SCRIPT_NAME'] . '?page=' . $_GET['page'] . '&action=download'.'">download file</a>';
  }
  ?>
  <div style="clear:both; padding-top:50px;"></div>
  <?php
  wp_nonce_field('save_statistics');
  echo '<input type="submit" value="reset all" name="reset_stats" />';
  echo '</form>';
  return;
}


 
// ---------------- END Admin Menus and Options ---------------- //


// ------------------------------------------------------------- //
// -- Functions Rotate Content Based on Preset -- //
// ------------------------------------------------------------- //


// Adds correct header information for current preset
function asf_rotate_header_info() {
	// assigns returned preset variable from function within class asf_rotate to new variable
	$preset = $_SESSION['asf_current_preset'];
	
	if ($preset == PresetName::EASTSIDE) {
		
		echo "<div id='heatmap-nav' style='color: #fff;'>";
		wp_nav_menu(array('theme_location' => PresetName::EASTSIDE, 'menu' => 'EastSide Menu' ));
		
		// wp_list_pages('title_li=');
		echo "</div>";
		
	}
	
}

// Rotates in the correct stylesheet
add_action('wp_head', 'asf_rotate_stylesheet');

function asf_rotate_stylesheet(){
		
	// assigns returned preset variable from function within class asf_rotate to new variable
	$preset = $_SESSION['asf_current_preset'];
			
	if ($preset == PresetName::TOWER_RIGHT) {	
		?>
			<link rel="stylesheet" href="<?php bloginfo('template_url') ?>/presets/tower-right/style-tower-right.css" type="text/css" />
		<?php
	}
	
	if ($preset == PresetName::TOWER_LEFT) {	
		?>
			<link rel="stylesheet" href="<?php bloginfo('template_url') ?>/presets/tower-left/style-tower-left.css" type="text/css" />
		<?php
	}
	
	if ($preset == PresetName::CENTRAL_BANK) {	
		?>
			<link rel="stylesheet" href="<?php bloginfo('template_url') ?>/presets/central-bank/style-central-bank.css" type="text/css" />
		<?php
	}
	
	if ($preset == PresetName::EASTSIDE) {	
		?>
			<link rel="stylesheet" href="<?php bloginfo('template_url') ?>/presets/eastside/style-eastside.css" type="text/css" />
		<?php
	}
	
	if ($preset == PresetName::SANDLOT) {	
		?>
			<link rel="stylesheet" href="<?php bloginfo('template_url') ?>/presets/sandlot/style-sandlot.css" type="text/css" />
		<?php
	}
}





// -------------------------------------------------------- //
// ---------- Ad Code Output Functions ---------- //
// -------------------------------------------------------- //

// 468 x 15 link unit
function asf_468x15_linkunit() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	// assign individual options to unique variables for logic purposes
	$pro_right_linkunit = $options[PresetName::TOWER_RIGHT . '_above_content_linkunit']; // <-- replace these with dynamic class constants then test out theme
	$pro_left_linkunit = $options[PresetName::TOWER_LEFT . '_above_content_linkunit'];
	
	// evaluate if Tower Right Preset is active and show ad accordingly
	if (!isset($pro_right_linkunit) || $pro_right_linkunit == '') {
		$topLinkDiv = '';
		$endTopLinkDiv = '';
	}
	
	elseif ($preset == PresetName::TOWER_RIGHT && !is_page(array('about-us', 'contact-us', 'privacy-policy')) ) {
		$topLinkDiv = '<div class="ad" id="top-link-unit">';
		$endTopLinkDiv = '</div>';
		
		echo $topLinkDiv;
		echo $options[PresetName::TOWER_RIGHT . "_above_content_linkunit"];
		echo $endTopLinkDiv;
	}
	
	// evaluate if Tower Left Preset is active and show ad accordingly
	if (!isset($pro_left_linkunit) || $pro_left_linkunit == '') {
		$topLinkDiv = '';
		$endTopLinkDiv = '';
	}
	
	elseif ($preset == PresetName::TOWER_LEFT && !is_page(array('about-us', 'contact-us', 'privacy-policy')) ) {
		
		$topLinkDiv = '<div class="ad" id="top-link-unit">';
		$endTopLinkDiv = '</div>';
		
		echo $topLinkDiv;
		echo $pro_left_linkunit;
		echo $endTopLinkDiv;
	}
}


// 728 x 15 link unit
function asf_728x15_linkunit() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	// assign individual options to unique variables for logic purposes
	$ctr_linkunit = $options[PresetName::CENTRAL_BANK . '_above_content_linkunit'];
	
	
	
	// evaluate if Central Bank Preset is active and show ad accordingly
	if (!isset($ctr_linkunit) || $ctr_linkunit == '') {
		$topLinkDiv = '';
		$endTopLinkDiv = '';
	}
	
	elseif ($preset == PresetName::CENTRAL_BANK && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		$topLinkDiv = '<div class="ad" id="top-link-unit">';
		$endTopLinkDiv = '</div>';
		
		echo $topLinkDiv;
		echo $options[PresetName::CENTRAL_BANK . '_above_content_linkunit'];
		echo $endTopLinkDiv;
	}
	
}


// register function for 728x15 linkunit in header
function asf_728x15_header_linkunit() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	// assign individual options to unique variables for logic purposes
	$small_header_linkunit = $options[PresetName::SANDLOT . '_linkunit'];

	// evaluate if Sandlot Preset is active and show ad accordingly
	if (!isset($small_header_linkunit) || $small_header_linkunit == '') {
		$topLinkDiv = '';
		$endTopLinkDiv = '';
	}
	
	elseif ($preset == PresetName::SANDLOT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		$topLinkDiv = '<div class="ad" id="header-linkunit">';
		$endTopLinkDiv = '</div>';
		
		echo $topLinkDiv;
		echo $options[PresetName::SANDLOT . '_linkunit'];
		echo $endTopLinkDiv;
	}
	
	
	
}




// 300 x 250 ad block
function asf_300x250_adblock() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::TOWER_RIGHT && !is_page(array('about-us', 'contact-us', 'privacy-policy') ) && $options[PresetName::TOWER_RIGHT . '_below_post_title'] ) {
		echo '<div class="ad" id="under-post-adblock">';
		echo $options[PresetName::TOWER_RIGHT . '_below_post_title'];
		echo '</div>';
	}
	
	if ($preset == PresetName::TOWER_LEFT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="under-post-adblock">';
		echo $options[PresetName::TOWER_LEFT . '_below_post_title'];
		echo '</div>';
	}
	
	if ($preset == PresetName::CENTRAL_BANK && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div id="under-title-ad-wrapper">';
		echo $options[PresetName::CENTRAL_BANK . '_below_title'];
		echo '</div>';
		
	}
	
	if ($preset == PresetName::SANDLOT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div id="under-post-adblock">';
		echo $options[PresetName::SANDLOT . '_under_post_block'];
		echo '</div>';
		
	}
	
	
}


// 468 x 60 ad banner in header
function asf_468x60_banner() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="header-banner">';
		echo $options[PresetName::EASTSIDE . '_head_banner'];
		echo '</div>';
	}
	
	
}


// 728 x 90 ad above post
function asf_728x60_ad_above_content() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="above-content-leaderboard">';
		echo $options[PresetName::EASTSIDE . '_above_content_leader'];
		echo '</div>';
	}
	
}



// 468 x 60 ad above post
function asf_468x60_ad_above_post() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="above-post-ad-small">';
		echo $options[PresetName::EASTSIDE . '_above_title_banner'];
		echo '</div>';
	}
	
}


// 468 x 60 ad below title
function asf_468x60_ad_below_title() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable 
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="below-title-ad">';
		echo $options[PresetName::EASTSIDE . '_below_title_banner'];
		echo '</div>';
	}
	
}


// 468 x 60 ad under content
function asf_468x60_ad_under_content() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::TOWER_RIGHT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))   && $options[PresetName::TOWER_RIGHT . '_under_content']  ) {
		echo'<div class="ad" id="under-content">';
		echo $options[PresetName::TOWER_RIGHT . '_under_content'];
		echo '</div>';
	}
	
	if ($preset == PresetName::TOWER_LEFT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="under-content">';
		echo $options[PresetName::TOWER_LEFT . '_under_content'];
		echo '</div>';
	}
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="under-content">';
		echo $options[PresetName::EASTSIDE . '_after_post_ad'];
		echo '</div>';
	}
	
	if ($preset == PresetName::SANDLOT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="under-content">';
		echo $options[PresetName::SANDLOT . '_under'];
		echo '</div>';
	}
	

}


// 336x280 ad under content
function asf_336x280_ad_under_content() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	

	if ($preset == PresetName::CENTRAL_BANK && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo '<div class="ad" id="under-content">';
		echo $options[PresetName::CENTRAL_BANK . '_below_page'];
		echo '</div>';
	}
		
}





// sidebar skyscraper ad 160x600
function asf_160x600_sidebar_ad() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::TOWER_RIGHT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sky-sidebar-ad">';
		echo $options[PresetName::TOWER_RIGHT . '_sidebar_sky'];
		echo '</div>';
	}
	
	if ($preset == PresetName::TOWER_LEFT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sky-sidebar-ad">';
		echo $options[PresetName::TOWER_LEFT . '_sidebar_sky'];
		echo '</div>';
	}
	
	if ($preset == PresetName::CENTRAL_BANK && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sky-sidebar-ad">';
		echo $options[PresetName::CENTRAL_BANK . '_sidebar_sky'];
		echo '</div>';
	}
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sky-sidebar-ad">';
		echo $options[PresetName::EASTSIDE . '_sidebar_sky'];
		echo '</div>';
	}
	
	if ($preset == PresetName::SANDLOT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sky-sidebar-ad">';
		echo $options[PresetName::SANDLOT . '_sky'];
		echo '</div>';
	}

	
}

// sidebar block unit ad 300x250
function asf_300x250_sidebar_ad() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	// assigns returned preset variable
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::EASTSIDE && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sidebar-block-ad">';
		echo $options[PresetName::EASTSIDE . '_sidebar_block'];
		echo '</div>';
	}

}


// sidebar linkunit ad 160x90
function asf_160x90_sidebar_ad() {
  global $post;
  
  $suppress_ad = get_post_meta($post->ID, 'asf_ad_control', true);
  if ($suppress_ad == 'on'){
    return;
  }
	
	// assigns returned preset variable
	$preset = $_SESSION['asf_current_preset'];
	
	// assigns ad code array to $options
	$options = get_option('preset_ad_code');
	
	if ($preset == PresetName::SANDLOT && !is_page(array('about-us', 'contact-us', 'privacy-policy'))) {
		echo'<div class="ad" id="sidebar-vert-linkunit">';
		echo $options[PresetName::SANDLOT . '_vert_unit'];
		echo '</div>';
	}
	
}




// ----------------------------------------------------------- //
// -------------- Misc. Theme Features --------------- //
// ----------------------------------------------------------- //


function asf_g_image_break() {
	// get options for theme
	$options = get_option('preset_ad_code');
	
	// assigns returned currently showing preset
	$preset = $_SESSION['asf_current_preset'];
	
	//preset names constants
	$name = array( 
		PresetName::TOWER_RIGHT, 
		PresetName::TOWER_LEFT, 
		PresetNAME::CENTRAL_BANK,
		PresetName::EASTSIDE,
		PresetName::SANDLOT
	);
	
	
	foreach ($name as $theme_name) {
		if ($preset == $theme_name) {
			if ($options[ $theme_name . '_g_image_break']  == 'on') {
				echo '<script language="Javascript1.1" type="text/Javascript">
					<!-- Hide from old browsers. if(parent.frames.length > 0) top.location.replace(document.location); 
					// Escape from any referring site\'s frame, but preserve one-click "Back". --></script> 
					</script>';
			}
			else {
				echo ' ';
			}
		}
	}
	
	
	//assign option Google Image break option to variable
	$g_image_break = $options[ $theme_name . '_g_image_break'] ;
	
}



function asf_rss_icon() {
	$preset = $_SESSION['asf_current_preset']; 
	
	if ($preset == PresetName::TOWER_RIGHT) {
			$theme_url = get_bloginfo('template_url');
	
			echo "<div id='rss-icon'><img src='$theme_url/presets/tower-right/images/rss-feed-icon.jpg' /></div>";
		}
		
	if ($preset == PresetName::TOWER_LEFT) {
			$theme_url = get_bloginfo('template_url');
	
			echo "<div id='rss-icon'><img src='$theme_url/presets/tower-left/images/rss-feed-icon.jpg' /></div>";
		}
	
}


add_action('wp_footer', 'adding_javascript_for_menu');

function adding_javascript_for_menu() {
	?>
		<script type="text/javascript">
		
			jQuery(document).ready(function(){

					jQuery("ul.menu li").hover(function() {

						jQuery(this).find('ul.sub-menu').stop(true, true).delay(50).animate({ "height": "show", "opacity": "show" }, 200 );

					}, function(){

						jQuery(this).find('ul.sub-menu').stop(true, true).delay(50).animate({ "height": "hide", "opacity": "hide" }, 200 );

						});
	
			});
			
		</script>
		
	
	<?php
	
	
}

?>